
{% if h.ctp_use_separate_route() and h.ctp_replace_dataset_button() %}
    {% set params = {} %}

    {% if group %}
        {% set params = {"owner_org": group} %}
    {% endif %}

    <a href="{{ h.url_for('create_typed_package.select_dataset_type', **params) }}" class="btn btn-primary">
        <i class="fa fa-plus-square"></i>
        Add Dataset
    </a>
{% else %}
    {% ckan_extends %}
{% endif %}
